Colour - Bibliography
=====================

Bibliography
------------

- Banterle, F., & Benedetti, L. (2014). PICCANTE: An Open and Portable Library for HDR Imaging.
- Banterle, F., Artusi, A., Debattista, K., & Chalmers, A. (2011a). 2.1.1 Generating HDR Content by Combining Multiple Exposures. Advanced High Dynamic Range Imaging. A K Peters/CRC Press. ISBN:978-1568817194
- Banterle, F., Artusi, A., Debattista, K., & Chalmers, A. (2011b). 3.2.1 Simple Mapping Methods. In Advanced High Dynamic Range Imaging (pp. 38–41). A K Peters/CRC Press. ISBN:978-1568817194
- Banterle, F., Artusi, A., Debattista, K., & Chalmers, A. (2011c). 3.2.2 Brightness Reproduction. Advanced High Dynamic Range Imaging. A K Peters/CRC Press. ISBN:978-1568817194
- Banterle, F., Artusi, A., Debattista, K., & Chalmers, A. (2011d). 3.2.3 Quantization Techniques. Advanced High Dynamic Range Imaging. A K Peters/CRC Press. ISBN:978-1568817194
- Banterle, F., Artusi, A., Debattista, K., & Chalmers, A. (2011e). Advanced High Dynamic Range Imaging. A K Peters/CRC Press. ISBN:978-1568817194
- Debevec, P., & Malik, J. (1997). Recovering High Dynamic Range Radiance Maps from Photographs, (August), 1–10. doi:10.1145/258734.258884
- Grossberg, M. D., & Nayar, S. K. (2003). Determining the camera response from images: What is knowable? IEEE Transactions on Pattern Analysis and Machine Intelligence, 25(11), 1455–1467. doi:10.1109/TPAMI.2003.1240119
- Habble, J. (2010a). Filmic Tonemapping Operators. Retrieved March 15, 2015, from http://filmicgames.com/archives/75
- Habble, J. (2010b). Uncharted 2: HDR Lighting. Retrieved March 15, 2015, from http://www.slideshare.net/ozlael/hable-john-uncharted2-hdr-lighting
- Reinhard, E., & Devlin, K. (2005). Dynamic range reduction inspired by photoreceptor physiology. IEEE Transactions on Visualization and Computer Graphics, 11(1), 13–24. doi:10.1109/TVCG.2005.9
- Schlick, C. (1994). Quantization Techniques for Visualization of High Dynamic Range Pictures. Proceedings of the Fifth Eurographics Workshop on Rendering, (Section 5), 7–18.
- Tumblin, J., Hodgins, J. K., & Guenter, B. K. (1999). Two methods for display of high contrast images. ACM Transactions on Graphics. doi:10.1145/300776.300783
- Wikipedia. (n.d.-a). EV as a measure of luminance and illuminance. Retrieved November 14, 2015, from https://en.wikipedia.org/wiki/Exposure_value#EV_as_a_measure_of_luminance_and_illuminance
- Wikipedia. (n.d.-b). Tonemapping - Purpose and methods. Retrieved March 15, 2015, from http://en.wikipedia.org/wiki/Tone_mapping#Purpose_and_methods

About
-----

| **Colour - HDRI** by Colour Developers - 2015
| Copyright © 2015 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour-hdri <http://github.com/colour-science/colour-hdri>`_
